==> kubernetes-model-node-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/node/v1/RuntimeClassListFluentImpl.java <==
package io.fabric8.kubernetes.api.model.node.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class RuntimeClassListFluentImpl<A extends RuntimeClassListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements RuntimeClassListFluent<A> {

    private String apiVersion;
    private List<RuntimeClassBuilder> items =  new ArrayList<RuntimeClassBuilder>();
    private String kind;
    private ListMeta metadata;

    public RuntimeClassListFluentImpl() {
    }

    public RuntimeClassListFluentImpl(RuntimeClassList instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,RuntimeClass item) {
        if (this.items == null) {this.items = new ArrayList<RuntimeClassBuilder>();}
        RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,RuntimeClass item) {
        if (this.items == null) {this.items = new ArrayList<RuntimeClassBuilder>();}
        RuntimeClassBuilder builder = new RuntimeClassBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(RuntimeClass... items) {
        if (this.items == null) {this.items = new ArrayList<RuntimeClassBuilder>();}
        for (RuntimeClass item : items) {RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<RuntimeClass> items) {
        if (this.items == null) {this.items = new ArrayList<RuntimeClassBuilder>();}
        for (RuntimeClass item : items) {RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(RuntimeClass... items) {
        for (RuntimeClass item : items) {RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<RuntimeClass> items) {
        for (RuntimeClass item : items) {RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<RuntimeClassBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<RuntimeClassBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          RuntimeClassBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<RuntimeClass> getItems() {
        return build(items);
    }

    public List<RuntimeClass> buildItems() {
        return build(items);
    }

    public RuntimeClass buildItem(int index) {
        return this.items.get(index).build();
    }

    public RuntimeClass buildFirstItem() {
        return this.items.get(0).build();
    }

    public RuntimeClass buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public RuntimeClass buildMatchingItem(Predicate<RuntimeClassBuilder> predicate) {
        for (RuntimeClassBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<RuntimeClassBuilder> predicate) {
        for (RuntimeClassBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withItems(List<RuntimeClass> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<RuntimeClassBuilder>(); for (RuntimeClass item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(RuntimeClass... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (RuntimeClass item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public RuntimeClassListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public RuntimeClassListFluent.ItemsNested<A> addNewItemLike(RuntimeClass item) {
        return new ItemsNestedImpl(-1, item);
    }

    public RuntimeClassListFluent.ItemsNested<A> setNewItemLike(int index,RuntimeClass item) {
        return new ItemsNestedImpl(index, item);
    }

    public RuntimeClassListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public RuntimeClassListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public RuntimeClassListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public RuntimeClassListFluent.ItemsNested<A> editMatchingItem(Predicate<RuntimeClassBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.test(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata() {
        return this.metadata;
    }

    public A withMetadata(ListMeta metadata) {
        this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        RuntimeClassListFluentImpl that = (RuntimeClassListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends RuntimeClassFluentImpl<RuntimeClassListFluent.ItemsNested<N>> implements RuntimeClassListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final RuntimeClassBuilder builder;
        private final int index;

            ItemsNestedImpl(int index,RuntimeClass item) {
                this.index = index;
                this.builder = new RuntimeClassBuilder(this, item);
                        
            }

            ItemsNestedImpl() {
                this.index = -1;
                this.builder = new RuntimeClassBuilder(this);
                        
            }

            public N and() {
                return (N) RuntimeClassListFluentImpl.this.setToItems(index,builder.build());
            }

            public N endItem() {
                return and();
            }
    }


}

==> kubernetes-model-node-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/node/v1/RuntimeClassListFluentImpl.java <==
package io.fabric8.kubernetes.api.model.node.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class RuntimeClassListFluentImpl<A extends RuntimeClassListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements RuntimeClassListFluent<A> {

    private String apiVersion;
    private List<RuntimeClassBuilder> items =  new ArrayList<RuntimeClassBuilder>();
    private String kind;
    private ListMeta metadata;

    public RuntimeClassListFluentImpl() {
    }

    public RuntimeClassListFluentImpl(RuntimeClassList instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,RuntimeClass item) {
        if (this.items == null) {this.items = new ArrayList<RuntimeClassBuilder>();}
        RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,RuntimeClass item) {
        if (this.items == null) {this.items = new ArrayList<RuntimeClassBuilder>();}
        RuntimeClassBuilder builder = new RuntimeClassBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(RuntimeClass... items) {
        if (this.items == null) {this.items = new ArrayList<RuntimeClassBuilder>();}
        for (RuntimeClass item : items) {RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<RuntimeClass> items) {
        if (this.items == null) {this.items = new ArrayList<RuntimeClassBuilder>();}
        for (RuntimeClass item : items) {RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(RuntimeClass... items) {
        for (RuntimeClass item : items) {RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<RuntimeClass> items) {
        for (RuntimeClass item : items) {RuntimeClassBuilder builder = new RuntimeClassBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<RuntimeClassBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<RuntimeClassBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          RuntimeClassBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<RuntimeClass> getItems() {
        return build(items);
    }

    public List<RuntimeClass> buildItems() {
        return build(items);
    }

    public RuntimeClass buildItem(int index) {
        return this.items.get(index).build();
    }

    public RuntimeClass buildFirstItem() {
        return this.items.get(0).build();
    }

    public RuntimeClass buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public RuntimeClass buildMatchingItem(Predicate<RuntimeClassBuilder> predicate) {
        for (RuntimeClassBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<RuntimeClassBuilder> predicate) {
        for (RuntimeClassBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withItems(List<RuntimeClass> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<RuntimeClassBuilder>(); for (RuntimeClass item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(RuntimeClass... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (RuntimeClass item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<A> addNewItemLike(RuntimeClass item) {
        return new ItemsNestedImpl(-1, item);
    }

    public io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<A> setNewItemLike(int index,RuntimeClass item) {
        return new ItemsNestedImpl(index, item);
    }

    public io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<A> editMatchingItem(Predicate<RuntimeClassBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.test(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata() {
        return this.metadata;
    }

    public A withMetadata(ListMeta metadata) {
        this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        RuntimeClassListFluentImpl that = (RuntimeClassListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends RuntimeClassFluentImpl<io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<N>> implements io.fabric8.kubernetes.api.model.node.v1.RuntimeClassListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final RuntimeClassBuilder builder;
        private final int index;

            ItemsNestedImpl(int index,RuntimeClass item) {
                this.index = index;
                this.builder = new RuntimeClassBuilder(this, item);
                        
            }

            ItemsNestedImpl() {
                this.index = -1;
                this.builder = new RuntimeClassBuilder(this);
                        
            }

            public N and() {
                return (N) RuntimeClassListFluentImpl.this.setToItems(index,builder.build());
            }

            public N endItem() {
                return and();
            }
    }


}
